﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.LightSwitch;
using Microsoft.LightSwitch.Security.Server;
using Microsoft.SharePoint.Client;

namespace LightSwitchApplication
{
    public partial class ApplicationDataService
    {
        private string _list = "Blue Yonder Records Management Site Requests";

        partial void SiteRequests_Inserted(SiteRequest entity)
        {
            this.CreateListItem(entity);
        }

        private void CreateListItem(SiteRequest entity)
        {
            using (ClientContext ctx = Application.SharePoint.GetAppWebClientContext())
            {
                Web web = ctx.Web;
                ListCollection lists = web.Lists;
                List list = lists.GetByTitle(this._list);
                ListItemCreationInformation ci = new ListItemCreationInformation();
                ListItem item = list.AddItem(ci);
                item["Title"] = entity.Title;
                item["SiteRequestId"] = entity.Id;
                item["DispositionPolicy"] = entity.DispositionPolicy;
                item["eDiscovery"] = entity.eDiscovery;
                item["ExternalShare"] = entity.ExternalShare;
                item["HIPPA"] = entity.HIPPA;
                item["RecordFormat"] = entity.RecordFormat;
                item["RecordType"] = entity.RecordType;
                item["RequirementsDescription"] = entity.Description;
                item.Update();
                ctx.ExecuteQuery();
            }
        }

        partial void SiteRequests_Updated(SiteRequest entity)
        {
            this.UpdateListItem(entity);
        }

        private void UpdateListItem(SiteRequest entity)
        {
            using (ClientContext ctx = Application.SharePoint.GetAppWebClientContext())
            {
                Web web = ctx.Web;
                ListCollection lists = web.Lists;
                List list = lists.GetByTitle(this._list);
                CamlQuery query = new CamlQuery();
                query.ViewXml = "<View><Query><Where><Contains><FieldRef Name='SiteRequestId'/><Value Type='Integer'>" + entity.Id.ToString() + "</Value></Contains></Where></Query></View>";
                ListItemCollection collection = list.GetItems(query);
                ctx.Load(collection);
                ctx.ExecuteQuery();
                ListItem item = collection[0];
                item["Title"] = entity.Title;
                item["DispositionPolicy"] = entity.DispositionPolicy;
                item["eDiscovery"] = entity.eDiscovery;
                item["ExternalShare"] = entity.ExternalShare;
                item["HIPPA"] = entity.HIPPA.ToString();
                item["RecordFormat"] = entity.RecordFormat;
                item["RecordType"] = entity.RecordType;
                item["RequirementsDescription"] = entity.Description;
                item.Update();
                ctx.ExecuteQuery();
            }
        }

        partial void SiteRequests_Deleted(SiteRequest entity)
        {
            this.DeleteListItem(entity);
        }

        private void DeleteListItem(SiteRequest entity)
        {
            try
            {
                using (ClientContext ctx = Application.SharePoint.GetAppWebClientContext())
                {
                    Web web = ctx.Web;
                    ListCollection lists = web.Lists;
                    List list = lists.GetByTitle(this._list);
                    CamlQuery query = new CamlQuery();
                    query.ViewXml = "<View><Query><Where><Contains><FieldRef Name='SiteRequestId'/><Value Type='Integer'>" + entity.Id.ToString() + "</Value></Contains></Where></Query></View>";
                    ListItemCollection collection = list.GetItems(query);
                    ctx.Load(collection);
                    ctx.ExecuteQuery();
                    ListItem item = collection[0];
                    item.DeleteObject();
                    ctx.ExecuteQuery();
                }
            }
            catch { }
        }
    }
}
